@@ -20,7 +20,7 @@ class OutputFormatterBase:
             result += f" ({node.size} bytes)"
 
         if node.is_ignored:
-            result += " [IGNORED]"
+            result += " [Status: IGNORED]"
 
         result += "\n"
 
@@ -33,6 +33,28 @@ class OutputFormatterBase:
                 result += self.generate_tree_string(child, prefix, i == len(children) - 1, show_size, show_ignored)
         return result
     
+    def generate_tree_string_for_LLM(self, node: NodeAnalysis):
+        """Generates a string representation of the directory tree readable by LLM."""
+
+        if node.is_ignored:
+            return ""
+
+        result = "- " + node.get_full_path()
+
+        if isinstance(node, DirectoryAnalysis):
+            result += "/"
+
+        if isinstance(node, TextFileAnalysis):
+            result += f" ({node.size} bytes)"
+
+        result += "\n"
+
+        if isinstance(node, DirectoryAnalysis):
+            children = node.children
+            for i, child in enumerate(children):
+                result += self.generate_tree_string_for_LLM(child)
+        return result
+
     def generate_content_string(self, data: NodeAnalysis):
         """Generates a structured representation of file contents."""
         content = []
@@ -58,12 +80,8 @@ class OutputFormatterBase:
         summary += f"Actual analyzed size: {data.get_non_ignored_text_content_size() / 1024:.2f} KB\n"
         summary += f"Total tokens: {data.get_total_tokens()}\n"
         summary += f"Actual text content size: {data.size / 1024:.2f} KB\n"
-        summary += f"Top largest files: {self.generate_top_files_string(data.get_largest_files())}\n"
-        summary += f"Top largest directories: {self.generate_top_directories_string(data.get_largest_directories())}\n"
-
-        ignored_files_string = self.generate_top_files_string([f for f in data._get_all_files() if f.is_ignored], prefix="- ")
-        if  ignored_files_string and ignored_files_string != "- Top 0 largest files:\n":
-            summary += f"\nTop ignored files (due to --ignore-top-files):\n {ignored_files_string}"
+        summary += f"Top largest non-ignored files:\n{self.generate_top_files_string(data.get_largest_files())}\n"
+        summary += f"Top largest non-ignored directories:\n{self.generate_top_directories_string(data.get_largest_directories())}\n"       
 
         return summary
 
@@ -71,9 +89,9 @@ class OutputFormatterBase:
         if not files:
             return f"{prefix}No large files found.\n"
 
-        output = f"{prefix}Top {len(files)} largest files:\n"
+        output = ""
         for file in files:
-             output += f"{prefix}- {file.get_full_path()} ({file.size} bytes)\n"
+             output += f"{prefix}- {file.get_full_path()} ({file.size / 1024:.2f} kB)\n"
 
         return output
 
@@ -81,9 +99,9 @@ class OutputFormatterBase:
         if not directories:
            return f"{prefix}No large directories found.\n"
 
-        output = f"{prefix}Top {len(directories)} largest directories:\n"
+        output = ""
         for directory in directories:
-            output += f"{prefix}- {directory.get_full_path()} ({directory.size} bytes)\n"
+            output += f"{prefix}- {directory.get_full_path()} ({directory.size / 1024:.2f} kB)\n"
         return output
     
 class PlainTextOutputFormatter(OutputFormatterBase):
@@ -91,17 +109,17 @@ class PlainTextOutputFormatter(OutputFormatterBase):
         return ".txt"
     
     def format(self, data: DirectoryAnalysis) -> str:
-        output = f"Parsed codebase for the project: {data.name}\n"
+        output = f"Parsed codebase for the project: {data.name}\n\n"
         output += "\nDirectory Structure:\n"
-        output += self.generate_tree_string(data, show_size=True, show_ignored=True)
+        output += self.generate_tree_string_for_LLM(data)
         output += self.generate_summary_string(data)
-        output += "\nFile Contents:\n"
+        output += "\nFile Contents:\n\n"
         for file in self.generate_content_string(data):
-            output += f"\n{'=' * 50}\n"
             output += f"File: {file['path']}\n"
-            output += f"{'=' * 50}\n"
+            output += f"---\n"
+            output += f"Content:\n"
             output += file['content']
-            output += "\n"
+            output += "\n\n"
         return output
 
 class MarkdownOutputFormatter(OutputFormatterBase):
@@ -111,15 +129,16 @@ class MarkdownOutputFormatter(OutputFormatterBase):
     def format(self, data: DirectoryAnalysis) -> str:
         output = f"# Parsed codebase for the project: {data.name}\n\n"
         output += "## Directory Structure\n\n"
-        output += "```\n"
-        output += self.generate_tree_string(data, show_size=True, show_ignored=True)
-        output += "```\n\n"
+        output += self.generate_tree_string_for_LLM(data)
+        output += "\n\n"
         output += "## Summary\n\n"
         output += f"- Total files: {data.get_file_count()}\n"
         output += f"- Total directories: {data.get_dir_count()}\n"
         output += f"- Total text file size (including ignored): {data.size / 1024:.2f} KB\n"
         output += f"- Total tokens: {data.get_total_tokens()}\n"
         output += f"- Analyzed text content size: {data.get_non_ignored_text_content_size() / 1024:.2f} KB\n\n"
+        output += f"Top largest non-ignored files:\n{self.generate_top_files_string(data.get_largest_files())}\n"
+        output += f"Top largest non-ignored directories:\n{self.generate_top_directories_string(data.get_largest_directories())}\n"       
         output += "## File Contents\n\n"
         for file in self.generate_content_string(data):
             output += f"### {file['path']}\n\n```\n{file['content']}\n```\n\n"
